@@ -122,7 +122,7 @@ renderer_new (GtkCellRenderer  *renderer,
 {
 	Renderer *ret = g_slice_new0 (Renderer);
 
-	ret->renderer = g_object_ref (renderer);
+	ret->renderer = g_object_ref_sink (renderer);
 	ret->position = position;
 
 	return ret;
@@ -961,6 +961,11 @@ on_view_expose_event (GtkSourceView   *view,
 		}
 	}
 
+	g_array_free (sizes, TRUE);
+	g_array_free (numbers, TRUE);
+	g_array_free (pixels, TRUE);
+	g_array_free (heights, TRUE);
+
 	return FALSE;
 }
 
@@ -1128,7 +1133,7 @@ on_view_button_press_event (GtkSourceView    *view,
 		g_free (path);
 		do_redraw (gutter);
 
-		return TRUE;
+		return ret;
 	}
 
 	return FALSE;
